==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/bytearray/ByteArrayAssert_doesNotContain_at_Index_with_Integer_Argument_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api.bytearray;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.data.Index.atIndex;
import static org.assertj.core.test.TestData.someIndex;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.ByteArrayAssert;
import org.assertj.core.api.ByteArrayAssertBaseTest;
import org.assertj.core.data.Index;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link ByteArrayAssert#doesNotContain(int, Index)}</code>.
 */
class ByteArrayAssert_doesNotContain_at_Index_with_Integer_Argument_Test extends ByteArrayAssertBaseTest {

  private final Index index = someIndex();

  @Override
  protected ByteArrayAssert invoke_api_method() {
    return assertions.doesNotContain(8, index);
  }

  @Override
  protected void verify_internal_effects() {
    verify(arrays).assertDoesNotContain(getInfo(assertions), getActual(assertions), 8, index);
  }

  @Test
  void invoke_api_like_user() {
    assertThat(new byte[] { 1 }).doesNotContain(2, atIndex(0));
  }
}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/bytearray/ByteArrayAssert_doesNotContain_at_Index_with_Integer_Argument_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api.bytearray;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.data.Index.atIndex;
import static org.assertj.core.testkit.TestData.someIndex;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.ByteArrayAssert;
import org.assertj.core.api.ByteArrayAssertBaseTest;
import org.assertj.core.data.Index;
import org.junit.jupiter.api.Test;

/**
 * Tests for <code>{@link ByteArrayAssert#doesNotContain(int, Index)}</code>.
 */
class ByteArrayAssert_doesNotContain_at_Index_with_Integer_Argument_Test extends ByteArrayAssertBaseTest {

  private final Index index = someIndex();

  @Override
  protected ByteArrayAssert invoke_api_method() {
    return assertions.doesNotContain(8, index);
  }

  @Override
  protected void verify_internal_effects() {
    verify(arrays).assertDoesNotContain(getInfo(assertions), getActual(assertions), 8, index);
  }

  @Test
  void invoke_api_like_user() {
    assertThat(new byte[] { 1 }).doesNotContain(2, atIndex(0));
  }
}
